missing files in previous submit
Gurusamy Sarathy [Fri, 31 Dec 1999 22:42:23 +0000 (22:42 +0000)]
p4raw-id: //depot/perl@4744

embed.h
embed.pl
ext/Devel/DProf/DProf.xs
globals.c
lib/ExtUtils/MM_Unix.pm
objXSUB.h
perlapi.c
proto.h

diff --git a/embed.h b/embed.h
index 95f3dd5..870e7e8 100644 (file)
--- a/embed.h
+++ b/embed.h
@@ -56,6 +56,8 @@
 #define malloced_size          Perl_malloced_size
 #endif
 #if defined(PERL_OBJECT)
+#ifndef __BORLANDC__
+#endif
 #endif
 #if defined(PERL_OBJECT)
 #else
 #define malloced_size          Perl_malloced_size
 #endif
 #if defined(PERL_OBJECT)
+#ifndef __BORLANDC__
+#endif
 #endif
 #if defined(PERL_OBJECT)
 #else
 #define malloced_size          Perl_malloced_size
 #endif
 #if defined(PERL_OBJECT)
+#ifndef __BORLANDC__
+#endif
 #endif
 #if defined(PERL_OBJECT)
 #else
index f04de69..db1ddf0 100755 (executable)
--- a/embed.pl
+++ b/embed.pl
@@ -324,7 +324,7 @@ walk_table {
     my $ret = "";
     if (@_ == 1) {
        my $arg = shift;
-       $ret .= "$arg\n" if $arg =~ /^#\s*(if|ifdef|else|endif)\b/;
+       $ret .= "$arg\n" if $arg =~ /^#\s*(if|ifn?def|else|endif)\b/;
     }
     else {
        my ($flags,$retval,$func,@args) = @_;
@@ -357,7 +357,7 @@ walk_table {
     my $ret = "";
     if (@_ == 1) {
        my $arg = shift;
-       $ret .= "$arg\n" if $arg =~ /^#\s*(if|ifdef|else|endif)\b/;
+       $ret .= "$arg\n" if $arg =~ /^#\s*(if|ifn?def|else|endif)\b/;
     }
     else {
        my ($flags,$retval,$func,@args) = @_;
@@ -417,7 +417,7 @@ walk_table {
     my $ret = "";
     if (@_ == 1) {
        my $arg = shift;
-       $ret .= "$arg\n" if $arg =~ /^#\s*(if|ifdef|else|endif)\b/;
+       $ret .= "$arg\n" if $arg =~ /^#\s*(if|ifn?def|else|endif)\b/;
     }
     else {
        my ($flags,$retval,$func,@args) = @_;
@@ -732,7 +732,7 @@ walk_table {
     my $ret = "";
     if (@_ == 1) {
        my $arg = shift;
-       $ret .= "$arg\n" if $arg =~ /^#\s*(if|ifdef|else|endif)\b/;
+       $ret .= "$arg\n" if $arg =~ /^#\s*(if|ifn?def|else|endif)\b/;
     }
     else {
        my ($flags,$retval,$func,@args) = @_;
@@ -943,7 +943,7 @@ walk_table {
     my $ret = "";
     if (@_ == 1) {
        my $arg = shift;
-       $ret .= "$arg\n" if $arg =~ /^#\s*(if|ifdef|else|endif)\b/;
+       $ret .= "$arg\n" if $arg =~ /^#\s*(if|ifn?def|else|endif)\b/;
     }
     else {
        my ($flags,$retval,$func,@args) = @_;
@@ -1068,7 +1068,9 @@ public:
        CPerlObj(IPerlMem*, IPerlMem*, IPerlMem*, IPerlEnv*, IPerlStdIO*,
            IPerlLIO*, IPerlDir*, IPerlSock*, IPerlProc*);
        void* operator new(size_t nSize, IPerlMem *pvtbl);
+#ifndef __BORLANDC__
        static void operator delete(void* pPerl, IPerlMem *pvtbl);
+#endif
        int do_aspawn (void *vreally, void **vmark, void **vsp);
 #endif
 #if defined(PERL_OBJECT)
index d0ac18a..6e9cfb3 100644 (file)
@@ -96,7 +96,9 @@ typedef struct {
     long long  start_cnt;
 #endif
 #ifdef PERL_IMPLICIT_CONTEXT
+#  define register
     pTHX;
+#  undef register
 #endif
 } prof_state_t;
 
index 80c659e..41dc924 100644 (file)
--- a/objXSUB.h
+++ b/objXSUB.h
 #if defined(MYMALLOC)
 #endif
 #if defined(PERL_OBJECT)
+#ifndef __BORLANDC__
+#endif
 #endif
 #if defined(PERL_OBJECT)
 #else
index 49dfeb6..d6c5d32 100644 (file)
--- a/perlapi.c
+++ b/perlapi.c
@@ -49,6 +49,8 @@ START_EXTERN_C
 #if defined(MYMALLOC)
 #endif
 #if defined(PERL_OBJECT)
+#ifndef __BORLANDC__
+#endif
 #endif
 #if defined(PERL_OBJECT)
 #else
@@ -5109,7 +5111,7 @@ Perl_ptr_table_split(pTHXo_ PTR_TBL_t *tbl)
 #if defined(PERL_IN_TOKE_C) || defined(PERL_DECL_PROT)
 #  if defined(CRIPPLED_CC)
 #  endif
-#  if defined(WIN32)
+#  if defined(PERL_CR_FILTER)
 #  endif
 #endif
 #if defined(PERL_IN_UNIVERSAL_C) || defined(PERL_DECL_PROT)
diff --git a/proto.h b/proto.h
index 06c834c..2118be4 100644 (file)
--- a/proto.h
+++ b/proto.h
@@ -43,7 +43,9 @@ public:
        CPerlObj(IPerlMem*, IPerlMem*, IPerlMem*, IPerlEnv*, IPerlStdIO*,
            IPerlLIO*, IPerlDir*, IPerlSock*, IPerlProc*);
        void* operator new(size_t nSize, IPerlMem *pvtbl);
+#ifndef __BORLANDC__
        static void operator delete(void* pPerl, IPerlMem *pvtbl);
+#endif
        int do_aspawn (void *vreally, void **vmark, void **vsp);
 #endif
 #if defined(PERL_OBJECT)
--- a/globals.c
+++ b/globals.c
@@ -45,12 +45,14 @@ CPerlObj::operator new(size_t nSize, IPerlMem *pvtbl)
 #endif
 }
 
+#ifndef __BORLANDC__
 void
 CPerlObj::operator delete(void *pPerl, IPerlMem *pvtbl)
 {
     if(pvtbl)
        pvtbl->pFree(pvtbl, pPerl);
 }
+#endif
 
 #ifdef WIN32           /* XXX why are these needed? */
 bool
index 4a07185..8940bf1 100644 (file)
@@ -377,10 +377,22 @@ sub cflags {
 
     if ($Is_PERL_OBJECT) {
         $self->{CCFLAGS} =~ s/-DPERL_OBJECT(\b|$)/-DPERL_CAPI/g;
-        if ($Is_Win32 && $Config{'cc'} =~ /^cl/i) {
-            # Turn off C++ mode of the MSC compiler
-            $self->{CCFLAGS} =~ s/-TP(\s|$)//;
-            $self->{OPTIMIZE} =~ s/-TP(\s|$)//;
+        if ($Is_Win32) { 
+           if ($Config{'cc'} =~ /^cl/i) {
+               # Turn off C++ mode of the MSC compiler
+               $self->{CCFLAGS} =~ s/-TP(\s|$)//g;
+               $self->{OPTIMIZE} =~ s/-TP(\s|$)//g;
+           }
+           elsif ($Config{'cc'} =~ /^bcc32/i) {
+               # Turn off C++ mode of the Borland compiler
+               $self->{CCFLAGS} =~ s/-P(\s|$)//g;
+               $self->{OPTIMIZE} =~ s/-P(\s|$)//g;
+           }
+           elsif ($Config{'cc'} =~ /^gcc/i) {
+               # Turn off C++ mode of the GCC compiler
+               $self->{CCFLAGS} =~ s/-xc\+\+(\s|$)//g;
+               $self->{OPTIMIZE} =~ s/-xc\+\+(\s|$)//g;
+           }
         }
     }
 
index 5c03183..56895c5 100644 (file)